searchData={"items":[{"type":"module","doc":"The main entrypoint for the Supabase SDK library.","title":"Supabase","ref":"Supabase.html"},{"type":"module","doc":"The package can be installed by adding `supabase_potion` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:supabase_potion, \"~> 0.3\"}\n      ]\n    end","title":"Installation - Supabase","ref":"Supabase.html#module-installation"},{"type":"module","doc":"After installing `:supabase_potion`, you can easily and dynamically manage different `Supabase.Client`!","title":"Usage - Supabase","ref":"Supabase.html#module-usage"},{"type":"module","doc":"The library offers a bunch of config options that can be used to control management of clients and other options.\n\n- `manage_clients` - whether to manage clients automatically, defaults to `true`\n\nYou can set up the library on your `config.exs`:\n\n    config :supabase, manage_clients: false","title":"Config - Supabase","ref":"Supabase.html#module-config"},{"type":"module","doc":"A `Supabase.Client`  holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\n`Supabase.Client` is defined as:\n\n- `:conn` - connection information, the only required option as it is vital to the `Supabase.Client`.\n  - `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.co`.\n  - `:api_key` - The API key used to authenticate requests to the Supabase API.\n  - `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n  - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n  - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n  - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n  - `:debug` - enable debug mode, defaults to `false`\n  - `:detect_session_in_url` - detect session in URL, defaults to `true`\n  - `:flow_type` - authentication flow type, defaults to `\"web\"`\n  - `:persist_session` - persist session, defaults to `true`\n  - `:storage` - storage type\n  - `:storage_key` - storage key","title":"Clients - Supabase","ref":"Supabase.html#module-clients"},{"type":"module","doc":"You then can start a Client calling `Supabase.init_client/1`:\n\n    iex> Supabase.init_client(%{db: %{schema: \"public\"}})\n    {:ok, %Supabase.Client{}}","title":"Starting a Client - Supabase","ref":"Supabase.html#module-starting-a-client"},{"type":"module","doc":"This package represents the base SDK for Supabase. That means\nthat it not includes all of the functionality of the Supabase client integrations, so you need to install each feature separetely, as:\n\n- [auth](https://github.com/zoedsoupe/gotrue-ex)\n- [storage](https://github.com/zoedsoupe/storage-ex)\n- [postgrest](https://github.com/zoedsoupe/postgrest-ex)\n- `realtime` - TODO\n- `ui` - TODO","title":"Acknowledgements - Supabase","ref":"Supabase.html#module-acknowledgements"},{"type":"module","doc":"Supabase Storage is a service for developers to store large objects like images, videos, and other files. It is a hosted object storage service, like AWS S3, but with a simple API and strong consistency.","title":"Supabase Storage - Supabase","ref":"Supabase.html#module-supabase-storage"},{"type":"module","doc":"PostgREST is a web server that turns your PostgreSQL database directly into a RESTful API. The structural constraints and permissions in the database determine the API endpoints and operations.","title":"Supabase PostgREST - Supabase","ref":"Supabase.html#module-supabase-postgrest"},{"type":"module","doc":"Supabase Realtime provides a realtime websocket API powered by PostgreSQL notifications. It allows you to listen to changes in your database, and instantly receive updates as soon as they happen.","title":"Supabase Realtime - Supabase","ref":"Supabase.html#module-supabase-realtime"},{"type":"module","doc":"Supabase Auth is a feature-complete user authentication system. It provides email & password sign in, email verification, password recovery, session management, and more, out of the box.","title":"Supabase Auth - Supabase","ref":"Supabase.html#module-supabase-auth"},{"type":"module","doc":"Supabase UI is a set of UI components that help you quickly build Supabase-powered applications. It is built on top of Tailwind CSS and Headless UI, and is fully customizable. The package provides `Phoenix.LiveView` components!","title":"Supabase UI - Supabase","ref":"Supabase.html#module-supabase-ui"},{"type":"function","doc":"","title":"Supabase.init_client/1","ref":"Supabase.html#init_client/1"},{"type":"function","doc":"","title":"Supabase.init_client!/1","ref":"Supabase.html#init_client!/1"},{"type":"function","doc":"","title":"Supabase.schema/0","ref":"Supabase.html#schema/0"},{"type":"module","doc":"A client for interacting with Supabase. This module is responsible for\nmanaging the connection options for your Supabase project.","title":"Supabase.Client","ref":"Supabase.Client.html"},{"type":"module","doc":"%Supabase.Client{\n      conn: %{\n        base_url: \"https:// .supabase.io\",\n        api_key: \" \",\n        access_token: \" \"\n      },\n      db: %Supabase.Client.Db{\n        schema: \"public\"\n      },\n      global: %Supabase.Client.Global{\n        headers: %{}\n      },\n      auth: %Supabase.Client.Auth{\n        auto_refresh_token: true,\n        debug: false,\n        detect_session_in_url: true,\n        flow_type: :implicit,\n        persist_session: true,\n        storage: nil,\n        storage_key: \"sb- -auth-token\"\n      }\n    }\n\n    iex> Supabase.Client.retrieve_connection(%Supabase.Client{})\n    %Supabase.Client.Conn{\n      base_url: \"https:// .supabase.io\",\n      api_key: \" \",\n      access_token: \" \"\n    }","title":"Examples - Supabase.Client","ref":"Supabase.Client.html#module-examples"},{"type":"function","doc":"","title":"Supabase.Client.parse/1","ref":"Supabase.Client.html#parse/1"},{"type":"function","doc":"","title":"Supabase.Client.parse!/1","ref":"Supabase.Client.html#parse!/1"},{"type":"function","doc":"Given a `Supabase.Client`, mounts the base url for the Auth/GoTrue feature.","title":"Supabase.Client.retrieve_auth_url/2","ref":"Supabase.Client.html#retrieve_auth_url/2"},{"type":"function","doc":"iex> Supabase.Client.retrieve_auth_url(%Supabase.Client{})\n    \"https:// .supabase.co/auth/v1\"","title":"Examples - Supabase.Client.retrieve_auth_url/2","ref":"Supabase.Client.html#retrieve_auth_url/2-examples"},{"type":"function","doc":"Given a `Supabase.Client`, return the raw the base url for the Supabase project.","title":"Supabase.Client.retrieve_base_url/1","ref":"Supabase.Client.html#retrieve_base_url/1"},{"type":"function","doc":"iex> Supabase.Client.retrieve_base_url(%Supabase.Client{})\n    \"https:// .supabase.co\"","title":"Examples - Supabase.Client.retrieve_base_url/1","ref":"Supabase.Client.html#retrieve_base_url/1-examples"},{"type":"function","doc":"Given a `Supabase.Client`, return the connection informations.","title":"Supabase.Client.retrieve_connection/1","ref":"Supabase.Client.html#retrieve_connection/1"},{"type":"function","doc":"iex> Supabase.Client.retrieve_connection(%Supabase.Client{})\n    %Supabase.Client.Conn{}","title":"Examples - Supabase.Client.retrieve_connection/1","ref":"Supabase.Client.html#retrieve_connection/1-examples"},{"type":"function","doc":"Given a `Supabase.Client`, mounts the base url for the Storage feature.","title":"Supabase.Client.retrieve_storage_url/2","ref":"Supabase.Client.html#retrieve_storage_url/2"},{"type":"function","doc":"iex> Supabase.Client.retrieve_storage_url(%Supabase.Client{})\n    \"https:// .supabase.co/storage/v1\"","title":"Examples - Supabase.Client.retrieve_storage_url/2","ref":"Supabase.Client.html#retrieve_storage_url/2-examples"},{"type":"function","doc":"","title":"Supabase.Client.update_access_token/2","ref":"Supabase.Client.html#update_access_token/2"},{"type":"type","doc":"","title":"Supabase.Client.params/0","ref":"Supabase.Client.html#t:params/0"},{"type":"type","doc":"","title":"Supabase.Client.t/0","ref":"Supabase.Client.html#t:t/0"},{"type":"module","doc":"Auth configuration schema. This schema is used to configure the auth\noptions. This schema is embedded in the `Supabase.Client` schema.","title":"Supabase.Client.Auth","ref":"Supabase.Client.Auth.html"},{"type":"module","doc":"- `:auto_refresh_token` - Automatically refresh the token when it expires. Defaults to `true`.\n- `:debug` - Enable debug mode. Defaults to `false`.\n- `:detect_session_in_url` - Detect session in URL. Defaults to `true`.\n- `:flow_type` - Authentication flow type. Defaults to `\"implicit\"`.\n- `:persist_session` - Persist session. Defaults to `true`.\n- `:storage` - Storage type.\n- `:storage_key` - Storage key. Default to `\"sb-$host-auth-token\"` where $host is the hostname of your Supabase URL.\n\nFor more information about the auth options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[auth guides](https://supabase.com/docs/guides/auth)","title":"Fields - Supabase.Client.Auth","ref":"Supabase.Client.Auth.html#module-fields"},{"type":"function","doc":"","title":"Supabase.Client.Auth.changeset/3","ref":"Supabase.Client.Auth.html#changeset/3"},{"type":"type","doc":"","title":"Supabase.Client.Auth.params/0","ref":"Supabase.Client.Auth.html#t:params/0"},{"type":"type","doc":"","title":"Supabase.Client.Auth.t/0","ref":"Supabase.Client.Auth.html#t:t/0"},{"type":"behaviour","doc":"Conn configuration for Supabase Client. This schema is used to configure\nthe connection options. This schema is embedded in the `Supabase.Client`.","title":"Supabase.Client.Conn","ref":"Supabase.Client.Conn.html"},{"type":"behaviour","doc":"- `:base_url` - The Supabase Project URL to use. This option is required.\n- `:api_key` - The Supabase ProjectAPI Key to use. This option is required.\n- `:access_token` - The access token to use. Default to the API key.\n\nFor more information about the connection options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing).","title":"Fields - Supabase.Client.Conn","ref":"Supabase.Client.Conn.html#module-fields"},{"type":"function","doc":"","title":"Supabase.Client.Conn.changeset/2","ref":"Supabase.Client.Conn.html#changeset/2"},{"type":"callback","doc":"","title":"Supabase.Client.Conn.changeset/2","ref":"Supabase.Client.Conn.html#c:changeset/2"},{"type":"callback","doc":"","title":"Supabase.Client.Conn.parse/1","ref":"Supabase.Client.Conn.html#c:parse/1"},{"type":"opaque","doc":"","title":"Supabase.Client.Conn.changeset/0","ref":"Supabase.Client.Conn.html#t:changeset/0"},{"type":"type","doc":"","title":"Supabase.Client.Conn.params/0","ref":"Supabase.Client.Conn.html#t:params/0"},{"type":"type","doc":"","title":"Supabase.Client.Conn.t/0","ref":"Supabase.Client.Conn.html#t:t/0"},{"type":"module","doc":"DB configuration schema. This schema is used to configure the database\noptions. This schema is embedded in the `Supabase.Client` schema.","title":"Supabase.Client.Db","ref":"Supabase.Client.Db.html"},{"type":"module","doc":"- `:schema` - The default schema to use. Defaults to `\"public\"`.\n\nFor more information about the database options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[database guides](https://supabase.com/docs/guides/database).","title":"Fields - Supabase.Client.Db","ref":"Supabase.Client.Db.html#module-fields"},{"type":"function","doc":"","title":"Supabase.Client.Db.changeset/2","ref":"Supabase.Client.Db.html#changeset/2"},{"type":"type","doc":"","title":"Supabase.Client.Db.params/0","ref":"Supabase.Client.Db.html#t:params/0"},{"type":"type","doc":"","title":"Supabase.Client.Db.t/0","ref":"Supabase.Client.Db.html#t:t/0"},{"type":"module","doc":"Global configuration schema. This schema is used to configure the global\noptions. This schema is embedded in the `Supabase.Client` schema.","title":"Supabase.Client.Global","ref":"Supabase.Client.Global.html"},{"type":"module","doc":"- `:headers` - The default headers to use in any Supabase request. Defaults to `%{}`.","title":"Fields - Supabase.Client.Global","ref":"Supabase.Client.Global.html#module-fields"},{"type":"function","doc":"","title":"Supabase.Client.Global.changeset/2","ref":"Supabase.Client.Global.html#changeset/2"},{"type":"type","doc":"","title":"Supabase.Client.Global.params/0","ref":"Supabase.Client.Global.html#t:params/0"},{"type":"type","doc":"","title":"Supabase.Client.Global.t/0","ref":"Supabase.Client.Global.html#t:t/0"},{"type":"module","doc":"A fundamental HTTP client for interfacing directly with Supabase services.\n\n`Supabase.Fetcher` provides the groundwork for sending HTTP requests to the Supabase infrastructure. This includes utilities for various HTTP methods such as GET, POST, PUT, DELETE, and functions to simplify the process of streaming data or uploading files.","title":"Supabase.Fetcher","ref":"Supabase.Fetcher.html"},{"type":"module","doc":"- **Low-level HTTP Interactions**: This module allows for raw HTTP requests to any URL, simplifying interactions with web resources.\n- **Data Streaming**: Efficiently stream large data payloads, such as downloading files.\n- **Request Customization**: Extensive header customization and utility functions for constructing requests tailored to your requirements.\n- **Response Parsing**: Automatically converts JSON responses into Elixir maps and handles various response scenarios.","title":"Key Features - Supabase.Fetcher","ref":"Supabase.Fetcher.html#module-key-features"},{"type":"module","doc":"While `Supabase.Fetcher` is versatile and comprehensive, it operates at a very granular level. For most applications and needs, leveraging higher-level APIs that correspond to specific Supabase services is advisable:\n\n- `Supabase.Storage` - API to interact directly with buckets and objects in Supabase Storage.","title":"Recommended Usage - Supabase.Fetcher","ref":"Supabase.Fetcher.html#module-recommended-usage"},{"type":"module","doc":"If your aim is to directly harness this module as a low-level HTTP client, due to missing features in other packages or a desire to craft a unique Supabase integration, you can certainly do so. However, always keep in mind that `Supabase.Storage` and other Supabase-oriented packages might offer better abstractions and ease-of-use.\n\nUse `Supabase.Fetcher` with a clear understanding of its features and operations.","title":"Disclaimer - Supabase.Fetcher","ref":"Supabase.Fetcher.html#module-disclaimer"},{"type":"function","doc":"","title":"Supabase.Fetcher.apply_client_headers/3","ref":"Supabase.Fetcher.html#apply_client_headers/3"},{"type":"function","doc":"Convenience function that given a `apikey` and a optional ` token`, it will return the headers\nto be used in a request to your Supabase API.","title":"Supabase.Fetcher.apply_headers/3","ref":"Supabase.Fetcher.html#apply_headers/3"},{"type":"function","doc":"iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer apikey-value\"}]\n\n     iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\", \"token-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer token-value\"}]","title":"Examples - Supabase.Fetcher.apply_headers/3","ref":"Supabase.Fetcher.html#apply_headers/3-examples"},{"type":"function","doc":"Simple DELETE request that format the response to a map or retrieve\nthe error reason as `String.t()`.","title":"Supabase.Fetcher.delete/4","ref":"Supabase.Fetcher.html#delete/4"},{"type":"function","doc":"iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}\n\n     iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:error, :not_found}","title":"Examples - Supabase.Fetcher.delete/4","ref":"Supabase.Fetcher.html#delete/4-examples"},{"type":"function","doc":"","title":"Supabase.Fetcher.format_response/1","ref":"Supabase.Fetcher.html#format_response/1"},{"type":"function","doc":"Simple GET request that format the response to a map or retrieve\nthe error reason as `String.t()`.","title":"Supabase.Fetcher.get/1","ref":"Supabase.Fetcher.html#get/1"},{"type":"function","doc":"iex> Supabase.Fetcher.get(\"https://example.com\")\n     {:ok, %{\"key\" => \"value\"}}","title":"Examples - Supabase.Fetcher.get/1","ref":"Supabase.Fetcher.html#get/1-examples"},{"type":"function","doc":"","title":"Supabase.Fetcher.get/2","ref":"Supabase.Fetcher.html#get/2"},{"type":"function","doc":"","title":"Supabase.Fetcher.get/3","ref":"Supabase.Fetcher.html#get/3"},{"type":"function","doc":"","title":"Supabase.Fetcher.get_full_url/2","ref":"Supabase.Fetcher.html#get_full_url/2"},{"type":"function","doc":"","title":"Supabase.Fetcher.get_header/2","ref":"Supabase.Fetcher.html#get_header/2"},{"type":"function","doc":"","title":"Supabase.Fetcher.get_header/3","ref":"Supabase.Fetcher.html#get_header/3"},{"type":"function","doc":"Simple HEAD request that format the response to a map or\nretrieve the error as `String.t()`","title":"Supabase.Fetcher.head/4","ref":"Supabase.Fetcher.html#head/4"},{"type":"function","doc":"","title":"Supabase.Fetcher.new_connection/4","ref":"Supabase.Fetcher.html#new_connection/4"},{"type":"function","doc":"Simple PATCH request that format the response to a map or\nretrieve the error as `String.t()`","title":"Supabase.Fetcher.patch/4","ref":"Supabase.Fetcher.html#patch/4"},{"type":"function","doc":"Simple POST request that format the response to a map or retrieve\nthe error reason as `String.t()`.","title":"Supabase.Fetcher.post/4","ref":"Supabase.Fetcher.html#post/4"},{"type":"function","doc":"iex> Supabase.Fetcher.post(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","title":"Examples - Supabase.Fetcher.post/4","ref":"Supabase.Fetcher.html#post/4-examples"},{"type":"function","doc":"Simple PUT request that format the response to a map or retrieve\nthe error reason as `String.t()`.","title":"Supabase.Fetcher.put/4","ref":"Supabase.Fetcher.html#put/4"},{"type":"function","doc":"iex> Supabase.Fetcher.put(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","title":"Examples - Supabase.Fetcher.put/4","ref":"Supabase.Fetcher.html#put/4-examples"},{"type":"function","doc":"Makes a HTTP request to the desired URL, with default headers and\nstream back the response. Good to stream large files downlaods.\n\nYou can also pass custom `Finch` options directly to the underlying `Finch.stream/4` function.\nThose options can be seen on the [Finch documentation](https://hexdocs.pm/finch/Finch.html#stream/5-options).","title":"Supabase.Fetcher.stream/3","ref":"Supabase.Fetcher.html#stream/3"},{"type":"function","doc":"iex> {status, stream} = Supabase.Fetcher.stream(\"https://example.com\")\n     iex> file = File.stream!(\"path/to/file\", [], 4096)\n     Stream.run Stream.into(stream, file)","title":"Examples - Supabase.Fetcher.stream/3","ref":"Supabase.Fetcher.html#stream/3-examples"},{"type":"function","doc":"Upload a binary to the desired URL.\n\nparams:\n- `method`: `:put` or `:post`\n- `url`: the URL to upload the file\n- `file`: the path to the file to upload\n- `headers`: list of additional headers to append to the request","title":"Supabase.Fetcher.upload/4","ref":"Supabase.Fetcher.html#upload/4"},{"type":"function","doc":"iex> Supabase.Fetcher.upload(:post, \"https://example.com\", \"path/to/file\")\n     {:ok, %{\"key\" => \"value\"}}","title":"Examples - Supabase.Fetcher.upload/4","ref":"Supabase.Fetcher.html#upload/4-examples"},{"type":"function","doc":"","title":"Supabase.Fetcher.version/0","ref":"Supabase.Fetcher.html#version/0"},{"type":"behaviour","doc":"Defines Supabase HTTP Clients callbacks","title":"Supabase.FetcherBehaviour","ref":"Supabase.FetcherBehaviour.html"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.delete/4","ref":"Supabase.FetcherBehaviour.html#c:delete/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.get/4","ref":"Supabase.FetcherBehaviour.html#c:get/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.head/4","ref":"Supabase.FetcherBehaviour.html#c:head/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.patch/4","ref":"Supabase.FetcherBehaviour.html#c:patch/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.post/4","ref":"Supabase.FetcherBehaviour.html#c:post/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.put/4","ref":"Supabase.FetcherBehaviour.html#c:put/4"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.stream/3","ref":"Supabase.FetcherBehaviour.html#c:stream/3"},{"type":"callback","doc":"","title":"Supabase.FetcherBehaviour.upload/4","ref":"Supabase.FetcherBehaviour.html#c:upload/4"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.body/0","ref":"Supabase.FetcherBehaviour.html#t:body/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.headers/0","ref":"Supabase.FetcherBehaviour.html#t:headers/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.method/0","ref":"Supabase.FetcherBehaviour.html#t:method/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.opts/0","ref":"Supabase.FetcherBehaviour.html#t:opts/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.reason/0","ref":"Supabase.FetcherBehaviour.html#t:reason/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.response/0","ref":"Supabase.FetcherBehaviour.html#t:response/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.result/0","ref":"Supabase.FetcherBehaviour.html#t:result/0"},{"type":"type","doc":"","title":"Supabase.FetcherBehaviour.url/0","ref":"Supabase.FetcherBehaviour.html#t:url/0"},{"type":"exception","doc":"","title":"Supabase.MissingSupabaseConfig","ref":"Supabase.MissingSupabaseConfig.html"},{"type":"extras","doc":"# Supabase Potion\n\nWhere the magic starts!","title":"Supabase Potion","ref":"readme.html"},{"type":"extras","doc":"","title":"Getting Started - Supabase Potion","ref":"readme.html#getting-started"},{"type":"extras","doc":"To install the base SDK:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.4\"}\n  ]\nend\n```","title":"Installation - Supabase Potion","ref":"readme.html#installation"},{"type":"extras","doc":"A `Supabase.Client` is an Agent that holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\n`Supabase.Client` is defined as:\n\n- `:name` - the name of the client, started by `start_link/1`\n- `:conn` - connection information, the only required option as it is vital to the `Supabase.Client`.\n    - `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.io`.\n    - `:api_key` - The API key used to authenticate requests to the Supabase API.\n    - `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n    - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n    - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n    - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n    - `:debug` - enable debug mode, defaults to `false`\n    - `:detect_session_in_url` - detect session in URL, defaults to `true`\n    - `:flow_type` - authentication flow type, defaults to `\"web\"`\n    - `:persist_session` - persist session, defaults to `true`\n    - `:storage` - storage type\n    - `:storage_key` - storage key","title":"Clients - Supabase Potion","ref":"readme.html#clients"},{"type":"extras","doc":"The Supabase Elixir SDK provides a flexible way to manage `Supabase.Client` instances, which can, in turn, manage multiple `Supabase.Client` instances. Here's a brief overview of the key concepts:","title":"Usage - Supabase Potion","ref":"readme.html#usage"},{"type":"extras","doc":"You can start a client using the `Supabase.Client.start_link/1` function. However, it's recommended to use `Supabase.init_client!/1`, which allows you to pass client options and automatically manage `Supabase.Client` processes.\n\n```elixir\niex> Supabase.Client.init_client!(%{conn: %{base_url: \" \", api_key: \" \"}})\n{:ok, #PID<0.123.0>}\n```","title":"Starting a Client - Supabase Potion","ref":"readme.html#starting-a-client"},{"type":"extras","doc":"Ensure your Supabase configurations are set:\n\n```elixir\nimport Config\n\nconfig :supabase,\n  manage_clients: false,\n  supabase_base_url: System.fetch_env!(\"SUPABASE_BASE_URL\"),\n  supabase_api_key: System.fetch_env!(\"SUPABASE_API_KEY\"),\n```\n\n- `supabase_base_url`: The base URL of your Supabase project! More information on how to find it can be seen on the [next section](#how-to-find-my-supabase-base-url?)\n- `supabase_api_key`: The secret of your Supabase project! More information on how to find it can be seen on the [next section](#how-to-find-my-supabase-api-key?)\n- `manage_clients`: Enable or disable the internal client management by the library. Defauls to `true`, see more on the [library supervisor documentation](https://hexdocs.pm/supabase_potion/Supabase.ClientSupervisor.html).\n\nMake sure to set the environment variables `SUPABASE_BASE_URL` and `SUPABASE_API_KEY`.","title":"Configuration - Supabase Potion","ref":"readme.html#configuration"},{"type":"extras","doc":"If you want to manually manage Clients, firstly you need to disable the config:\n\n```elixir\nimport Config\n  \nconfig :supabase_potion, manage_clients: false\n```\n\nThen you need to start the Clients managements processes, that consists on:\n- `Supabase.ClientSupervisor`: a DynamicSupervisor to manage multiple Supabase clients\n- `Supabase.ClientRegistry`: a Registry to easily find a Supabase client\n\nYou can start them on your application startup, often on your `MyApp.Application`:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    children = [\n      # rest of your Supervisor's children...\n      # is recommended to start registry **before**\n      # the Supervsior\n      Supabase.ClientRegistry\n      Supabase.ClientSupervisor\n    ]\n  end\n\n  # rest of module...\nend\n```\n\nNow you can start to initialize Clients! as pointed on [Staring a Client](#starting-a-client) section.\n\nHowever, maybe you can full control of your Supabase Clients, then, you can start Clients individually on your application startup, like:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    supabase_config = supabase_client_config()\n    supabase_opts = [name: MyApp.SupabaseClient, client_info: supabase_config]\n\n    children = [\n      # rest of your Supervisor's children...\n      {Supabase.Client, supabase_opts}\n    ]\n  end\n\n  defp supabase_client_config do\n    %{\n      # you can skip the `conn` config if you already set on config.exs\n      conn: %{ \n        api_key: \"my-super-secret-api-key\",\n        base_url: \"https://my-project-id.supabase.co\",\n        access_token: \"my-scoped-access-token\",\n      },\n      db: %{schema: \"my-schema\"} # default to \"public\",\n      # global headers to be used on Supabase API requests\n      global: %{headers: %{\"content-type\": \"application/json\"}},\n      auth: %{\n        # below are the defaults values\n        auto_refresh_token: true,\n        debug: false,\n        detect_session_in_url: true,\n        flow_type: :implicit,\n        persist_session: true,\n        storage: \"my-storage\",\n        storage_key: \"my-storage-key\"\n      }\n    }\n  end\n\n  # rest of module...\nend\n```\n\n#### TODO","title":"Manually starting Clients - Supabase Potion","ref":"readme.html#manually-starting-clients"},{"type":"extras","doc":"You can find your Supabase base URL in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe base URL is the first field on the page.","title":"How to find my Supabase base URL? - Supabase Potion","ref":"readme.html#how-to-find-my-supabase-base-url"},{"type":"extras","doc":"You can find your Supabase API key in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe API key is the second field on the page.\n\nThere two types of API keys, the public and the private. The last one\nbypass any Row Level Security (RLS) rules you have set up.\nSo you shouldn't use it in your frontend application.\n\nIf you don't know what RLS is, you can read more about it here:\nhttps://supabase.com/docs/guides/auth/row-level-security\n\nFor most cases you should prefer to use the public \"anon\" Key.","title":"How to find my Supabase API Key? - Supabase Potion","ref":"readme.html#how-to-find-my-supabase-api-key"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}